bluebook

package
v0.0.0-...-2d66b3c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 7, 2024 License: AGPL-3.0 Imports: 1 Imported by: 0

Documentation

Overview

As Structural Engineers adopt digital workflows, the availability of data in consumable formats becomes increasingly important. Structural design data is often captured within Excel spreadsheets, books, tables and figures, which is inconvenient from a software perspective. Moreover, mapping data from one format to another can be time-consuming and a frequent source of error. The bluebook package encapsulates the Steel for Life steel section data as a library with a stable and convenient API. The original .xlsx data files were sourced from: https://www.steelforlifebluebook.co.uk.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DimensionsAndProperties

type DimensionsAndProperties struct {
	Depth                      units.Millimetre
	Width                      units.Millimetre
	Length                     units.Millimetre
	TotalMass                  units.Kilogram
	MassPerMetreLength         float64
	CrossSectionalArea         float64
	SurfaceAreaPerMetre        float64
	SurfaceAreaPerTonne        float64
	WebThickness               float64
	FlangeThickness            float64
	RootRadius                 float64
	DepthBetweenFillets        float64
	EndClearanceForDetailing   float64
	LongitudinalNotchDimension float64
	VerticalNotchDimension     float64
	RadiusOfGyration           float64
}

Jump to